summaryrefslogtreecommitdiff
path: root/gcc/compiler-probe.h
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/compiler-probe.h')
-rw-r--r--gcc/compiler-probe.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/gcc/compiler-probe.h b/gcc/compiler-probe.h
index c527ae83642..f5c445316c9 100644
--- a/gcc/compiler-probe.h
+++ b/gcc/compiler-probe.h
@@ -166,27 +166,27 @@ typedef HOST_WIDE_INT comprobe_ix_t;
#ifdef TREE_CODE /*TREE_CODE is an important macro from tree.h */
/***
- * return true if a (GIMPLE/SSA) tree TR has a position
+ * return true if a (GIMPLE/SSA) tuple G has a position
* and in that case fill the PFILENAME and PLINENO
* if the END flag is set, return the last position
***/
enum { POS_START = 0, POS_END };
-bool comprobe_get_position (tree tr, char **pfilename, int *plineno, int end);
+bool comprobe_get_gimple_position (gimple g, char **pfilename, int *plineno, int end);
/***
* return a unique positive file rank for the location of a tree, if
* any (else 0); may send a PROB_file request to the probe and set the
* *plineno to the line number
**/
-int comprobe_file_rank_of_tree (tree tr, int *plineno);
+int comprobe_file_rank_of_gimple (gimple g, int *plineno);
/****
- * we manage a unique mapping between trees and indexes thru our hash
+ * we manage a unique mapping between gimples and indexes thru our hash
* table; to get the index of a tree and vice versa the tree of an
* index
***/
-comprobe_ix_t comprobe_unique_index_of_tree (tree tr);
-tree comprobe_tree_of_unique_index (comprobe_ix_t ix);
+comprobe_ix_t comprobe_unique_index_of_gimple (gimple g);
+gimple comprobe_gimple_of_unique_index (comprobe_ix_t ix);
#endif /*TREE_CODE */
@@ -230,8 +230,8 @@ basic_block comprobe_basic_block_of_unique_index (comprobe_ix_t ix);
#define comprobe_unique_index_of_tree(T) (0 && (T) == (tree)0)
#define comprobe_tree_of_unique_index(I) NULL_TREE
#define comprobe_filerank(P) (0 && (P) == (const char*)0)
-#define comprobe_get_position(T,PF,PL,E) (FALSE \
- && (T)!=(tree)0 \
+#define comprobe_get_gimple_position(G,PF,PL,E) (FALSE \
+ && (G)!=(gimple)0 \
&& (PF)!=(char**0) \
&& (PL) != (int*)0 && (E))
#define comprobe_infopoint_add_displayer(IRK,DMESG,DROUT,DATA) while(0 && \
@@ -411,7 +411,7 @@ typedef HOST_WIDE_INT comprobe_ix_t;
* if the END flag is set, return the last position
***/
enum { POS_START = 0, POS_END };
-bool comprobe_get_position (tree tr, char **pfilename, int *plineno, int end);
+bool comprobe_get_gimple_position (gimple g, char **pfilename, int *plineno, int end);
/***
* return a unique positive file rank for the location of a tree, if
@@ -166,27 +166,27 @@ typedef HOST_WIDE_INT comprobe_ix_t;
/***
- * return a unique positive file rank for the location of a tree, if
+ * return a unique positive file rank for the location of a gimple, if
* any (else 0); may send a PROB_file request to the probe and set the
* *plineno to the line number